// pages/login/login.js
import {userLogin} from '../../api/login.js'
import { oidcUrl } from '../../environments.js'
import { getPermission } from '../../api/permission.js'
Page({

    /**
     * 页面的初始数据
     */
    data: {
        form: {
            username: '',
            password: ''
        },
        remember: false,
        formRules: {
            username: {
                validator: function(value) {
                    return value.trim() != ''
                },
                tips: '请输入用户名',
                placeholder: '请输入用户名',
                isPassword: false
            },
            password: {
                validator: function(value) {
                    return value.trim() != ''
                },
                tips: '请输入密码',
                placeholder: '请输入密码',
                isPassword: true
            }
        }
    },

    /**
     * 生命周期函数--监听页面显示
     */
    onShow: function () {
        // 隐藏返回图标
        wx.hideHomeButton();
        // 判断是否有记住密码
        if(wx.getStorageSync('remember')) {
            this.setData({
                rememberChecked: true
            })
            this.setData({
                form: wx.getStorageSync('loginForm')
            })
        }
    },
    // 记住密码
    checkboxChange(e) {
        let checked = this.data.remember
        this.setData({remember: !checked})
    },
    bindValue(e) {
        let name = e.currentTarget.dataset.name;
        let form = this.data.form;
        form[name] = e.detail.value;
        this.setData({
            form,
        })
        this.validate(name, e.detail.value)
    },
    validate(name) {
        let formRules = this.data.formRules;
        let validator = this.data.formRules[name].validator
        let result = validator ? !validator(this.data.form[name]) : false;
        formRules[name].warning = result
        this.setData({
            formRules
        })
        return result
    },
    validateForm() {
        return new Promise((resolve, reject) => {
            try {
                let formRules = this.data.formRules;
                let result = false;
                for (let key in formRules) {
                    let temp = this.validate(key)
                    if (temp) {
                        result = temp
                    }
                }
                resolve(!result)
            } catch (e) {
                reject(e)
            }
        })
    },
    submitForm() {
        this.validateForm().then(res => {
            if (res) {
                wx.showLoading({title: "登录中", mask:true});
                // 判断是否有记住密码
                if(this.data.remember) {
                    wx.setStorageSync('remember', true)
                    wx.setStorageSync('loginForm', this.data.form)
                } else {
                    wx.removeStorageSync('remember')
                    wx.removeStorageSync('loginForm')
                }
                const that = this
                const data = {
                    username: that.data.form.username,
                    password: that.data.form.password,
                    grant_type: 'password',
                    scope: 'openid profile',
                    // 'client_id': 'tuoheng-dsp-mp',
                    // 'client_secret': '3uPRJjTxHO6EXjjAzsyyHQ=='
                    'client_id': 'tuoheng-pilot-mp',
                    'client_secret': 'aKVXeHSkgDPqWT3whyIcA=='
                  }


                wx.request({
                    url: `${oidcUrl}/oauth2/token`,
                    method: "POST",
                    data: data,
                    header: {
                        'content-type': 'application/x-www-form-urlencoded',
                    },
                    success(res) {
                        if(res.statusCode === 200 ){
                            if(res.data.access_token) {
                                const token = `${res.data.token_type} ${res.data.access_token}`
                                wx.setStorage({ key:'token', data: token})
                                wx.request({
                                  url: `${oidcUrl}/user/getInfo`,
                                  method: 'POST',
                                  data:{
                                    username: that.data.form.username
                                  },
                                  header: {
                                    'Content-Type': 'application/json',
                                    Authorization: token
                                  },
                                  success: function(user) {
                                      if(user.data.code === 0){
                                          let dataForm = user.data.data
                                          if(dataForm.authorityList.includes('admin') || dataForm.authorityList.includes('tuoheng-pilot-mp')) {
                                              // 获取用户信息
                                              userLogin().then(res=> {
                                                wx.hideLoading();
                                                if(res.code === 0) {
                                                    wx.setStorage({
                                                        key: 'userInfo',
                                                        data: res.data
                                                    })
                                                    // 获取用户权限信息
                                                    getPermission(res.data.roleId).then(i => {
                                                        if (i.code === 0) {
                                                            wx.setStorage({
                                                                key: 'menuList',
                                                                data: i.data.opMenusList
                                                            })
                                                            wx.setStorage({
                                                                key: 'permissionsList',
                                                                data: i.data.permissionsList
                                                            })
                                                        }
                                                    })
                                                    wx.switchTab({
                                                        url: '/pages/task/task',
                                                    })
                                                }
                                            })
                                        }
                                    }else{
                                      wx.showToast({
                                        title: user.data.msg,
                                        icon: 'none',
                                        duration: 2000
                                      })
                                    }
                                  }
                                })
                            }
                            if(res.data.includes('登录页面')) {
                                wx.showToast({
                                    icon: 'error',
                                    title: '账号或密码错误',
                                    duration: 2000
                                })
                            }
                        } else {
                            wx.hideLoading();
                            wx.showToast({
                                title:'用户名或密码错误',
                                icon:"none",
                                duration: 2000
                            })
                        }
                    },
                    fail(error) {
                        wx.hideLoading();
                        wx.showToast({
                            title:'用户名或密码错误',
                            icon:"error",
                            duration: 2000
                        })
                    }
                })
            }
        })
    }
})